@@ -32,7 +32,7 @@ class Indexer(object):
         self.fields = {
             'AutoField': 'long',
             'BigIntegerField': 'long',
-            'BinaryField': 'sring',
+            'BinaryField': 'string',
             'BooleanField': 'boolean',
             'CharField': 'string',
             'CommaSeparatedIntegerField': 'string',
